pub enum ServiceAccountError {
Io {
file: PathBuf,
error: Error,
},
Parse(Error),
InvalidKey(Error),
}Expand description
An error occurring when loading the service account file.
Variants
Io
The service account file could not be read.
Fields
Parse(Error)
The service account JSON could not be parsed into the expected format.
InvalidKey(Error)
The private key was invalid.