pub struct ServiceAccount { /* private fields */ }Expand description
A representation of a GCP service account file. Contains the information required to obtain an access token via OAuth.
Implementations
Sourceimpl ServiceAccount
impl ServiceAccount
Sourcepub fn read_from_file(
path: impl AsRef<Path>,
) -> Result<Self, ServiceAccountError>
pub fn read_from_file( path: impl AsRef<Path>, ) -> Result<Self, ServiceAccountError>
Reads the service account JSON file at path and attempts to parse it.
Sourcepub fn read_from_canonical_env() -> Result<Self, ServiceAccountError>
pub fn read_from_canonical_env() -> Result<Self, ServiceAccountError>
Reads the ServiceAccount from the file pointed to by the
GOOGLE_APPLICATION_CREDENTIALS environment variable.